@@ -9,9 +9,7 @@ from pymysql import Connect
 
 from logging import info, basicConfig, INFO
 
-from pyutils_spirit.util import Assemble, HashAssemble
-
-from pyutils_spirit.exception import NoneSignatureError
+from pyutils_spirit.exception.exception import NoneSignatureError
 
 basicConfig(level=INFO)
 
@@ -21,7 +19,7 @@ class Annotation:
 
     __cursor = None
 
-    __assemble: Assemble[str, object] = None
+    __assemble: dict[str, object] = None
 
     __lock: Lock = None
 
@@ -56,7 +54,7 @@ class Annotation:
                 raise NoneSignatureError
 
             if cls.__assemble is None:
-                cls.__assemble = HashAssemble()
+                cls.__assemble = dict()
 
             def get_signature(other_cls) -> callable:
 
@@ -65,7 +63,7 @@ class Annotation:
                     if instance is None:
                         # 创建新实例并存储
                         instance = other_cls(*args, **kwargs)
-                        cls.__assemble.put(signature, instance)
+                        cls.__assemble[signature] = instance
                     return instance
 
                 get_instance.__decorator__ = "singleton"
