@@ -2,17 +2,17 @@
 # @Time: 2024/9/11 0:15
 # @Author: xieyang_ls
 # @Filename: mysql_handler.py
-import datetime
-
 from abc import ABC, abstractmethod
 
 from logging import info, error, INFO, basicConfig
 
-from pyutils_spirit.annotation import singleton
+from pyutils_spirit.util.json_util import deep_loads
 
 from pymysql import Connect, OperationalError, cursors
 
-from pyutils_spirit.exception import ArgumentException
+from pyutils_spirit.annotation.interpreter import singleton
+
+from pyutils_spirit.exception.exception import ArgumentException
 
 basicConfig(level=INFO)
 
@@ -36,7 +36,7 @@ class Handler(ABC):
         pass
 
     @abstractmethod
-    def manageExecute(self, sql: str) -> bool:
+    def manage_execute(self, sql: str) -> bool:
         pass
 
     @abstractmethod
@@ -44,7 +44,7 @@ class Handler(ABC):
         pass
 
     @abstractmethod
-    def getConnection(self) -> [Connect]:
+    def get_connection(self) -> [Connect]:
         pass
 
 
@@ -54,57 +54,30 @@ class MySQLHandler(Handler):
 
     __connection = None
 
-    def __init__(self, args: dict[str, str | int]) -> None:
+    def __init__(self, host: str, port: int, user: str, password: str, database: str) -> None:
         try:
             connection: Connect = Connect(
-                host=args["host"],
-                port=args["port"],
-                user=args["user"],
-                password=args["password"],
-                cursorclass=cursors.DictCursor
+                host=host,
+                port=port,
+                user=user,
+                password=password,
+                cursorclass=cursors.SSDictCursor
             )
-            connection.select_db(args["database"])
-            info(f"Connected to database {args['database']} successfully!!!")
+            connection.select_db(database)
+            info(f"Connected to database {database} successfully!!!")
             info(f"MySQL version: {connection.get_server_info()}")
             cursor = connection.cursor()
             self.__connection = connection
             self.__cursor = cursor
-        except (ArgumentException, OperationalError):
-            error(f"Connected to database {args['database']} failure")
+        except (ArgumentException, OperationalError) as e:
+            error(e)
+            error(f"Connected to database {database} failure")
             raise ArgumentException("please check connected the database arguments")
 
-    def __json_format_list(self, results: list[dict] | tuple[dict]) -> list:
-        if isinstance(results, list | tuple):
-            for result in results:
-                if result is None:
-                    continue
-                self.__json_format_dict(result)
-        return results
-
-    def __json_format_dict(self, result: dict) -> dict:
-        for key in result.keys():
-            attribute = result[key]
-            if attribute is None:
-                continue
-            if isinstance(attribute, dict):
-                result[key] = self.__json_format_dict(attribute)
-            elif isinstance(attribute, list):
-                result[key] = self.__json_format_list(attribute)
-            else:
-                if isinstance(attribute, datetime.datetime):
-                    result[key] = attribute.isoformat()
-        return result
-
-    def select(self, sql: str) -> list | tuple | dict:
-        try:
-            self.__cursor.execute(sql)
-            results = self.__cursor.fetchall()
-            return self.__json_format_list(results)
-        except OperationalError as e:
-            if e.args[0] == 1054:
-                return []
-            else:
-                raise e
+    def select(self, sql: str) -> tuple:
+        self.__cursor.execute(sql)
+        result: tuple = self.__cursor.fetchall()
+        return deep_loads(data=result)
 
     def insert(self, sql: str) -> bool:
         try:
@@ -133,7 +106,7 @@ class MySQLHandler(Handler):
             self.__connection.rollback()
             raise e
 
-    def manageExecute(self, sql: str) -> bool:
+    def manage_execute(self, sql: str) -> bool:
         try:
             self.__cursor.execute(sql)
             self.__connection.commit()
@@ -142,7 +115,7 @@ class MySQLHandler(Handler):
             self.__connection.rollback()
             raise e
 
-    def getConnection(self) -> [Connect]:
+    def get_connection(self) -> [Connect]:
         return self.__connection, self.__cursor
 
     def disconnect(self) -> None:
