@@ -3,11 +3,12 @@
 # @Author: xieyang_ls
 # @Filename: __init__.py.py
 
-from pyutils_spirit.tcp.websocket import WebSocketServer, Session, onopen, onmessage, onclose, onerror
+from pyutils_spirit.tcp.websocket import WebSocketServer, EndPoint, onopen, onmessage, onerror, onclose, Session
 
 __all__ = ['WebSocketServer',
-           'Session',
+           'EndPoint',
            'onopen',
            'onmessage',
+           'onerror',
            'onclose',
-           'onerror']
+           'Session']
